@@ -1,4 +1,4 @@
-(* $Id: gears.ml,v 1.2 2001/09/06 08:47:55 garrigue Exp $ *)
+(* $Id: gears.ml,v 1.2.4.1 2004/03/11 01:19:43 garrigue Exp $ *)
 
 (*
  * 3-D gear wheels.  This program is in the public domain.
@@ -254,4 +254,4 @@ let main () =
   window#show ();
   Main.main ()
 
-let _ = Printexc.print main ()
+let () = if not !Sys.interactive then Printexc.print main ()
