@@ -1,4 +1,4 @@
-(* $Id: planet.ml,v 1.6 2001/09/06 08:47:55 garrigue Exp $ *)
+(* $Id: planet.ml,v 1.6.4.1 2004/03/11 01:19:43 garrigue Exp $ *)
 
 open StdLabels
 
@@ -124,4 +124,4 @@ let main () =
   w#show ();
   Main.main ()
 
-let _ = Printexc.print main ()
+let () = if not !Sys.interactive then Printexc.print main ()
