@@ -1,4 +1,4 @@
-(* $Id: simple.ml,v 1.5 2000/04/24 09:07:29 garrigue Exp $ *)
+(* $Id: simple.ml,v 1.5.6.1 2004/03/11 01:19:43 garrigue Exp $ *)
 
 open GMain
 
@@ -30,4 +30,4 @@ let main () =
   w#show ();
   Main.main ()
 
-let _ = main ()
+let () = if not !Sys.interactive then Printexc.print main ()
