@@ -1,4 +1,8 @@
-(* $Id: csview.ml,v 1.8 2001/10/09 08:43:19 garrigue Exp $ *)
+(* $Id: csview.ml,v 1.9 2002/06/19 15:08:40 garrigue Exp $ *)
+
+(* Compile with
+   ocamlc -pp camlp4o -I +lablgtk lablgtk.cma csview.ml -o csview
+*)
 
 open StdLabels
 
@@ -121,6 +125,7 @@ let main argv =
     exit 2
   end;
   let data = read_file argv.(1) in
+  let locale = Main.init ~setlocale:true () in
   let w = GWindow.window () in
   w#misc#realize ();
   let style = w#misc#style in
