@@ -1,4 +1,4 @@
-(* $Id: test.ml,v 1.2 2001/09/06 08:47:56 garrigue Exp $ *)
+(* $Id: test.ml,v 1.3 2002/01/25 01:22:21 garrigue Exp $ *)
 
 open StdLabels
 
@@ -17,7 +17,7 @@ let test_string2 = String.concat ~sep:"" [
 let read_file file =
   let ic = open_in file in
   let b = Buffer.create 16384 and s = String.create 1024 and len = ref 0 in
-  while len := input' ic ~buf:s ~pos:0 ~len:1024; !len > 0 do
+  while len := input ic s 0 1024; !len > 0 do
     Buffer.add_substring b s 0 !len
   done;
   Buffer.contents b
