@@ -1,4 +1,4 @@
-(* $Id: gContainer.ml,v 1.14 2001/09/06 08:47:56 garrigue Exp $ *)
+(* $Id: gContainer.ml,v 1.15 2002/05/30 05:49:09 garrigue Exp $ *)
 
 open StdLabels
 open Gaux
@@ -69,7 +69,7 @@ class virtual ['a] item_container obj = object (self)
 end
 
 class item_signals obj = object
-  inherit container_signals obj
+  inherit container_signals (obj : [> Gtk.item] obj)
   method select = GtkSignal.connect ~sgn:Item.Signals.select obj ~after
   method deselect = GtkSignal.connect ~sgn:Item.Signals.deselect obj ~after
   method toggle = GtkSignal.connect ~sgn:Item.Signals.toggle obj ~after
