@@ -1,4 +1,4 @@
-(* $Id: gDraw.mli,v 1.13 2001/10/04 09:45:40 garrigue Exp $ *)
+(* $Id: gDraw.mli,v 1.16 2002/06/19 10:09:53 garrigue Exp $ *)
 
 open Gdk
 
@@ -42,6 +42,10 @@ class ['a] drawable : ?colormap:colormap -> 'a Gdk.drawable ->
     method put_pixmap :
       x:int -> y:int ->
       ?xsrc:int -> ?ysrc:int -> ?width:int -> ?height:int -> pixmap -> unit
+    method put_rgb_data :
+      width:int -> height:int ->
+      ?x:int -> ?y:int -> ?dither:Gdk.Tags.rgb_dither ->
+      ?row_stride:int -> Gpointer.region -> unit
     method rectangle :
       x:int ->
       y:int -> width:int -> height:int -> ?filled:bool -> unit -> unit
@@ -96,8 +100,9 @@ class type misc_ops =
   end
 
 val pixmap :
+  width:int -> height:int -> ?mask:bool ->
   ?window:< misc : #misc_ops; .. > -> ?colormap:colormap ->
-  width:int -> height:int -> ?mask:bool -> unit -> pixmap
+  unit -> pixmap
 val pixmap_from_xpm :
   file:string ->
   ?window:< misc : #misc_ops; .. > ->
@@ -112,5 +117,5 @@ class drag_context : Gdk.drag_context ->
     val context : Gdk.drag_context
     method status : ?time:int -> Tags.drag_action list -> unit
     method suggested_action : Tags.drag_action
-    method targets : atom list
+    method targets : string list
   end
