@@ -1,4 +1,4 @@
-(* $Id: gList.mli,v 1.27 2001/10/09 08:43:56 garrigue Exp $ *)
+(* $Id: gList.mli,v 1.29.2.1 2003/05/15 14:18:34 furuse Exp $ *)
 
 open Gtk
 open GObj
@@ -53,7 +53,7 @@ val liste :
 class clist_signals : 'a obj ->
   object
     inherit container_signals
-    constraint 'a = [>`clist|`container|`widget]
+    constraint 'a = [> clist]
     val obj : 'a obj
     method click_column : callback:(int -> unit) -> GtkSignal.id
     method select_row :
@@ -145,6 +145,8 @@ class ['a] clist : Gtk.clist obj ->
     method unselect : int -> int -> unit
     method unselect_all : unit -> unit
     method vadjustment : GData.adjustment
+    method get_row_state : int -> Gtk.Tags.state_type
+    method selection : int list
   end
 val clist :
   ?columns:int ->
