@@ -1,4 +1,4 @@
-(* $Id: gMain.ml,v 1.8 2001/05/23 03:12:20 garrigue Exp $ *)
+(* $Id: gMain.ml,v 1.10 2002/07/06 03:02:31 garrigue Exp $ *)
 
 open Gtk
 open GtkMain
@@ -13,8 +13,12 @@ module Grab = struct
   let get_current () = new widget (get_current ())
 end
 
+module Rc = Rc
+
 module Timeout = Timeout
 
+module Io = Glib.Io
+
 open Main
 let main = main
 let quit = quit
