@@ -1,4 +1,4 @@
-(* $Id: gMisc.mli,v 1.26 2001/11/22 09:22:07 garrigue Exp $ *)
+(* $Id: gMisc.mli,v 1.28 2002/05/30 05:49:09 garrigue Exp $ *)
 
 open Gtk
 open GObj
@@ -37,7 +37,7 @@ val statusbar :
 class calendar_signals : 'a obj ->
   object
     inherit widget_signals
-    constraint 'a = [>`calendar|`widget]
+    constraint 'a = [> calendar]
     val obj : 'a obj
     method day_selected : callback:(unit -> unit) -> GtkSignal.id
     method day_selected_double_click :
@@ -86,7 +86,7 @@ val drawing_area :
 class misc : 'a obj ->
   object
     inherit widget
-    constraint 'a = [>`misc|`widget]
+    constraint 'a = [> Gtk.misc]
     val obj : 'a obj
     method set_alignment : ?x:float -> ?y:float -> unit -> unit
     method set_padding : ?x:int -> ?y:int -> unit -> unit
@@ -95,7 +95,7 @@ class misc : 'a obj ->
 class arrow : 'a obj ->
   object
     inherit misc
-    constraint 'a = [>`arrow|`misc|`widget]
+    constraint 'a = [> Gtk.arrow]
     val obj : 'a obj
     method set_arrow : Tags.arrow_type -> shadow:Tags.shadow_type -> unit
   end
@@ -114,7 +114,7 @@ val arrow :
 class image : 'a obj ->
   object
     inherit misc
-    constraint 'a = [>`image|`misc|`widget]
+    constraint 'a = [> Gtk.image]
     val obj : 'a obj
     method set_image : ?mask:Gdk.bitmap -> Gdk.image -> unit
   end
@@ -133,7 +133,7 @@ val image :
 class label_skel : 'a obj ->
   object
     inherit misc
-    constraint 'a = [>`label|`misc|`widget]
+    constraint 'a = [> Gtk.label]
     val obj : 'a obj
     method set_justify : Tags.justification -> unit
     method set_line_wrap : bool -> unit
@@ -165,7 +165,7 @@ val label_cast : < as_widget : 'a obj ; .. > -> label
 class tips_query_signals : 'a obj ->
   object
     inherit widget_signals
-    constraint 'a = [>`tipsquery|`widget]
+    constraint 'a = [> Gtk.tips_query]
     val obj : 'a obj
     method widget_entered :
       callback:(widget option ->
@@ -263,3 +263,28 @@ val font_selection :
   ?width:int ->
   ?height:int ->
   ?packing:(widget -> unit) -> ?show:bool -> unit -> font_selection
+
+
+class preview :
+  Gtk.preview Gtk.obj ->
+  object
+    inherit widget_full
+    val obj : Gtk.preview Gtk.obj
+    method draw_row : data:int array -> x:int -> y:int -> unit
+    method event : GObj.event_ops
+    method put :
+      ?xsrc:int ->
+      ?ysrc:int ->
+      ?xdest:int ->
+      ?ydest:int -> ?width:int -> ?height:int -> Gdk.window -> Gdk.gc -> unit
+    method set_dither : Gdk.Tags.rgb_dither -> unit
+    method set_expand : bool -> unit
+    method size : width:int -> height:int -> unit
+  end
+val preview :
+  ?kind:Gtk.Tags.preview_type ->
+  ?dither:Gdk.Tags.rgb_dither ->
+  ?expand:bool ->
+  ?width:int ->
+  ?height:int ->
+  ?packing:(GObj.widget -> unit) -> ?show:bool -> unit -> preview
