@@ -1,4 +1,4 @@
-(* $Id: gdk.ml,v 1.49 2001/10/04 09:45:40 garrigue Exp $ *)
+(* $Id: gdk.ml,v 1.57.2.3 2003/07/10 09:48:44 oandrieu Exp $ *)
 
 open StdLabels
 open Gaux
@@ -68,6 +68,21 @@ module Tags = struct
   type drag_action =
     [ `DEFAULT|`COPY|`MOVE|`LINK|`PRIVATE|`ASK ]
 
+  type rgb_dither = 
+    [ `NONE|`NORMAL|`MAX]
+
+  type selection = [ `PRIMARY | `SECONDARY ]
+
+  type property_state = [ `NEW_VALUE | `DELETE ]
+
+  type property_mode = [ `REPLACE | `PREPEND | `APPEND ]
+
+  type xdata =
+    [ `BYTES of string
+    | `SHORTS of int array
+    | `INT32S of int32 array ]
+
+  type xdata_ret = [ xdata | `NONE ]
 end
 open Tags
 
@@ -80,9 +95,34 @@ module Convert = struct
       ~f:(fun m -> test_modifier m i)
 end
 
+module Atom = struct
+  external intern : string -> bool -> atom = "ml_gdk_atom_intern"
+  let intern ?(dont_create=false) name = intern name dont_create
+  external name : atom -> string = "ml_gdk_atom_name"
+end
+
+module Property = struct
+  external change :
+      window ->
+      property:atom -> typ:atom -> mode:property_mode -> xdata -> unit
+      = "ml_gdk_property_change"
+  let change ~window ~typ ?(mode=`REPLACE) property data =
+    change window ~property ~typ ~mode data
+  external get :
+      window -> property:atom ->
+      max_length:int -> delete:bool -> (atom * xdata) option
+      = "ml_gdk_property_get"
+  let get ~window ?(max_length=65000) ?(delete=false) property =
+    get window ~property ~max_length ~delete
+  external delete : window:window -> atom -> unit
+      = "ml_gdk_property_delete"
+end
+
 module Screen = struct
   external width : unit -> int = "ml_gdk_screen_width"
   external height : unit -> int = "ml_gdk_screen_height"
+  external width_mm : unit -> int = "ml_gdk_screen_width_mm"
+  external height_mm : unit -> int = "ml_gdk_screen_height_mm"
 end
 
 module Visual = struct
@@ -184,9 +224,13 @@ module Window = struct
   external get_size : 'a drawable -> int * int = "ml_gdk_window_get_size"
   external get_position : 'a drawable -> int * int =
     "ml_gdk_window_get_position"
+  external get_pointer_location: window -> int * int =
+    "ml_gdk_window_get_pointer_location"
   external root_parent : unit -> window = "ml_GDK_ROOT_PARENT"
   external set_back_pixmap : window -> pixmap -> int -> unit = 
     "ml_gdk_window_set_back_pixmap"
+  external set_cursor : window -> cursor -> unit = 
+    "ml_gdk_window_set_cursor"
   external clear : window -> unit = "ml_gdk_window_clear"
   external get_xwindow : 'a drawable -> xid = "ml_GDK_WINDOW_XWINDOW"
 
@@ -406,23 +450,29 @@ module Draw = struct
       = "ml_gdk_draw_polygon"
   let polygon w gc ?(filled=false) l =
     f_pointarray (polygon w gc ~filled) l
-  external string : 'a drawable -> font: font -> gc -> x: int -> y: int ->
-    string: string -> unit
-      = "ml_gdk_draw_string_bc" "ml_gdk_draw_string"	
-  external image : 'a drawable -> gc -> image: image -> 
+  external string :
+    'a drawable -> font: font -> gc -> x: int -> y: int -> string -> unit
+     = "ml_gdk_draw_string_bc" "ml_gdk_draw_string"	
+  external image_ : 'a drawable -> gc -> image -> 
     xsrc: int -> ysrc: int -> xdest: int -> ydest: int -> 
     width: int -> height: int -> unit
-      = "ml_gdk_draw_image_bc" "ml_gdk_draw_image"
+    = "ml_gdk_draw_image_bc" "ml_gdk_draw_image"
+  let image w gc ?(xsrc=0) ?(ysrc=0) ?(xdest=0) ?(ydest=0)
+      ?(width= -1) ?(height= -1) image =
+    image_ w gc image ~xsrc ~ysrc ~xdest ~ydest ~width ~height
 (*
   external bitmap : 'a drawable -> gc -> bitmap: bitmap -> 
     xsrc: int -> ysrc: int -> xdest: int -> ydest: int -> 
     width: int -> height: int -> unit
       = "ml_gdk_draw_bitmap_bc" "ml_gdk_draw_bitmap"
 *)
-  external pixmap : 'a drawable -> gc -> pixmap: pixmap -> 
+  external pixmap_ : 'a drawable -> gc -> pixmap -> 
     xsrc: int -> ysrc: int -> xdest: int -> ydest: int -> 
     width: int -> height: int -> unit
-      = "ml_gdk_draw_pixmap_bc" "ml_gdk_draw_pixmap"
+    = "ml_gdk_draw_pixmap_bc" "ml_gdk_draw_pixmap"
+  let pixmap w gc ?(xsrc=0) ?(ysrc=0) ?(xdest=0) ?(ydest=0)
+      ?(width= -1) ?(height= -1) pixmap =
+    pixmap_ w gc pixmap ~xsrc ~ysrc ~xdest ~ydest ~width ~height
 
   external points : 'a drawable -> gc -> PointArray.t -> unit
       = "ml_gdk_draw_points"
@@ -432,13 +482,25 @@ module Draw = struct
   let lines w gc l = f_pointarray (lines w gc) l
   external segments : 'a drawable -> gc -> SegmentArray.t -> unit
       = "ml_gdk_draw_segments"
-  let segments w gc l = f_segmentarray (segments w gc) l
+  let segments w gc = function
+    | [] -> ()
+    | l -> f_segmentarray (segments w gc) l
 end
 
 module Rgb = struct
   external init : unit -> unit = "ml_gdk_rgb_init"
   external get_visual : unit -> visual = "ml_gdk_rgb_get_visual"
   external get_cmap : unit -> colormap = "ml_gdk_rgb_get_cmap"
+  external draw_image_ :
+    'a drawable -> gc -> x:int -> y:int -> width:int -> height:int ->
+    dither:rgb_dither -> buf:Gpointer.region -> row_stride:int -> unit
+    = "ml_gdk_draw_rgb_image_bc" "ml_gdk_draw_rgb_image"
+  let draw_image w gc ~width ~height ?(x=0) ?(y=0) ?(dither=`NORMAL)
+    ?(row_stride=width*3) buf =
+    if height <= 0 || width <= 0 || row_stride < width * 3
+    || Gpointer.length buf < row_stride * (height - 1) + width
+    then invalid_arg "Gdk.Rgb.draw_image";
+    draw_image_ w gc ~x ~y ~width ~height ~dither ~buf ~row_stride
 end
 
 module DnD = struct
@@ -601,3 +663,12 @@ module Cursor = struct
     = "ml_gdk_cursor_new_from_pixmap_bc" "ml_gdk_cursor_new_from_pixmap"
   external destroy : cursor -> unit = "ml_gdk_cursor_destroy"
 end
+
+module Input = struct
+  type callback_id
+  type condition = [`READ|`WRITE|`EXCEPTION] 
+  external add : Unix.file_descr -> cond: condition -> callback: (unit -> unit) -> callback_id = 
+    "ml_gdk_input_add"
+  external remove : callback_id -> unit
+      = "ml_gdk_input_remove"
+end
