@@ -1,4 +1,4 @@
-(* $Id: gtkBin.ml,v 1.7 2001/11/22 09:22:07 garrigue Exp $ *)
+(* $Id: gtkBin.ml,v 1.8 2002/05/30 05:49:09 garrigue Exp $ *)
 
 open Gaux
 open Gtk
@@ -92,10 +92,12 @@ module HandleBox = struct
     may snap_edge ~f:(set_snap_edge w)
   module Signals = struct
     open GtkSignal
-    let child_attached : ([>`handlebox],_) t =
-      { name = "child_attached"; marshaller = Widget.Signals.marshal }
-    let child_detached : ([>`handlebox],_) t =
-      { name = "child_detached"; marshaller = Widget.Signals.marshal }
+    let child_attached =
+      { name = "child_attached"; classe = `handlebox;
+        marshaller = Widget.Signals.marshal }
+    let child_detached =
+      { name = "child_detached"; classe = `handlebox;
+        marshaller = Widget.Signals.marshal }
   end
 end
 
