@@ -1,4 +1,4 @@
-(* $Id: gtkTree.ml,v 1.8 2001/03/12 03:43:43 garrigue Exp $ *)
+(* $Id: gtkTree.ml,v 1.9 2002/05/30 05:49:09 garrigue Exp $ *)
 
 open Gaux
 open Gtk
@@ -25,10 +25,10 @@ module TreeItem = struct
       = "ml_GTK_TREE_ITEM_SUBTREE"
   module Signals = struct
     open GtkSignal
-    let expand : ([>`treeitem],_) t =
-      { name = "expand"; marshaller = marshal_unit }
-    let collapse : ([>`treeitem],_) t =
-      { name = "collapse"; marshaller = marshal_unit }
+    let expand =
+      { name = "expand"; classe = `treeitem; marshaller = marshal_unit }
+    let collapse =
+      { name = "collapse"; classe = `treeitem; marshaller = marshal_unit }
   end
 end
 
@@ -62,12 +62,14 @@ module Tree = struct
     may_set set_view_lines view_lines
   module Signals = struct
     open GtkSignal
-    let selection_changed : ([>`tree],_) t =
-      { name = "selection_changed"; marshaller = marshal_unit }
-    let select_child : ([>`tree],_) t =
-      { name = "select_child"; marshaller = Widget.Signals.marshal }
-    let unselect_child : ([>`tree],_) t =
-      { name = "unselect_child"; marshaller = Widget.Signals.marshal }
+    let selection_changed =
+      { name = "selection_changed"; classe = `tree; marshaller = marshal_unit }
+    let select_child =
+      { name = "select_child"; classe = `tree;
+        marshaller = Widget.Signals.marshal }
+    let unselect_child =
+      { name = "unselect_child"; classe = `tree;
+        marshaller = Widget.Signals.marshal }
   end
 end
 (*
