@@ -1,4 +1,4 @@
-(* $Id: gtkWindow.ml,v 1.15.2.1 2003/06/11 09:08:33 garrigue Exp $ *)
+(* $Id: gtkWindow.ml,v 1.15.2.2 2003/10/30 02:36:25 garrigue Exp $ *)
 
 open Gaux
 open Gtk
@@ -122,6 +122,8 @@ module FileSelection = struct
       = "ml_gtk_file_selection_get_help_button"
   external get_file_list : [>`filesel] obj -> clist obj
       = "ml_gtk_file_selection_get_file_list"
+  external get_dir_list : [>`filesel] obj -> clist obj
+      = "ml_gtk_file_selection_get_dir_list"
   let set_fileop_buttons w = function
       true -> show_fileop_buttons w
     | false -> hide_fileop_buttons w
