@@ -1,4 +1,4 @@
-/* $Id: ml_gdk.c,v 1.53 2002/07/16 07:54:06 garrigue Exp $ */
+/* $Id: ml_gdk.c,v 1.59.2.5 2003/07/10 09:48:44 oandrieu Exp $ */
 
 #include <string.h>
 #include <gdk/gdk.h>
@@ -32,6 +32,8 @@ void ml_raise_gdk (const char *errmsg)
 Make_OptFlags_val (GdkModifier_val)
 Make_Flags_val (Event_mask_val)
 
+#include <stdio.h>
+
 #define Make_test(conv) \
 CAMLprim value ml_test_##conv (value mask, value test) \
 { return Val_bool (conv(mask) & Int_val(test)); }
@@ -46,6 +48,8 @@ ML_0 (gdk_colormap_get_system, Val_GdkColormap)
 /* Screen geometry */
 ML_0 (gdk_screen_width, Val_int)
 ML_0 (gdk_screen_height, Val_int)
+ML_0 (gdk_screen_width_mm, Val_int)
+ML_0 (gdk_screen_height_mm, Val_int)
 
 /* Visual */
 CAMLprim value ml_gdk_visual_get_best (value depth, value type)
@@ -225,6 +229,18 @@ CAMLprim value ml_gdk_window_get_size (value window)
   return ret;
 }
 
+CAMLprim value ml_gdk_window_get_pointer_location (value window)
+{
+  int x = 0;
+  int y = 0;
+  value ret;
+  gdk_window_get_pointer (GdkWindow_val(window), &x, &y, NULL);
+  ret = alloc_small (2, 0);
+  Field(ret, 0) = Val_int(x);
+  Field(ret, 1) = Val_int(y);
+  return ret;
+}
+
 /* Cursor */
 
 ML_1 (gdk_cursor_new, GdkCursorType_val, Val_GdkCursor)
@@ -312,8 +328,106 @@ Make_Extractor (GdkFont, GdkFont_val, descent, Val_int)
 
 /* Properties */
 
-ML_2 (gdk_atom_intern, String_val, Int_val, Val_int)
-ML_1 (gdk_atom_name, Int_val, Val_string)
+ML_2 (gdk_atom_intern, String_val, Int_val, Val_GdkAtom)
+ML_1 (gdk_atom_name, GdkAtom_val, copy_string_g_free)
+
+CAMLprim value ml_gdk_property_change(value window, value property, value type,
+                                      value mode, value xdata)
+{
+    int format = Xdata_val (Field(xdata,0));
+    value data = Field(xdata,1);
+    int nelems = (format == 8 ? string_length (data) : Wosize_val(data));
+    guchar *sdata;
+    int i;
+    switch (format) {
+    case 16:
+        sdata = calloc(nelems, sizeof(short)); 
+        for (i=0; i<nelems; i++)
+            ((gushort*)sdata)[i] = Int_val(Field(data,i));
+        break;
+    case 32:
+        sdata = calloc(nelems, sizeof(long));
+        for (i=0; i<nelems; i++)
+            ((gulong*)sdata)[i] = Int32_val(Field(data,i)); 
+        break;
+    default:
+        sdata = (guchar*)data;
+    }
+    gdk_property_change (GdkWindow_val(window), GdkAtom_val(property),
+                         GdkAtom_val(type), format, Property_mode_val(mode),
+                         sdata, nelems);
+    if (format != 8) free(sdata);
+    return Val_unit;
+}
+
+/* copy X11 property data */
+value copy_xdata (gint format, guchar *xdata, gulong nitems)
+{
+    CAMLparam0();
+    CAMLlocal2(ret, data);
+    int i, tag;
+    switch (format) {
+    case 8:
+        data = alloc_string (nitems);
+        memcpy (String_val(data), xdata, sizeof(char) * nitems);
+        tag = MLTAG_BYTES;
+        break;
+    case 16:
+        data = alloc (nitems,0);
+        for (i = 0; i < nitems; i++)
+            Field(data,i) = Val_int(((short*)xdata)[i]);
+        tag = MLTAG_SHORTS;
+        break;
+    case 32:
+        data = alloc (nitems,0);
+        for (i = 0; i < nitems; i++)
+            Store_field(data, i, copy_int32 (((long*)xdata)[i]));
+        tag = MLTAG_INT32S;
+        break;
+    default:
+        tag = MLTAG_NONE;
+    }
+    if (tag != MLTAG_NONE) {
+        ret = alloc_small (2,0);
+        Field(ret,0) = tag;
+        Field(ret,1) = data;
+    }
+    else ret = tag;
+    CAMLreturn(ret);
+}
+
+CAMLprim value ml_gdk_property_get (value window, value property,
+                                    value length, value pdelete)
+{
+    GdkAtom atype;
+    int aformat, alength;
+    guchar *data;
+    int nitems;
+    int ok = gdk_property_get (GdkWindow_val(window), GdkAtom_val(property),
+                               0, 0,
+                               Long_val(length), Bool_val(pdelete),
+                               &atype, &aformat, &alength, &data);
+
+    if (ok) {
+        CAMLparam0();
+        CAMLlocal3(mltype, mldata, pair);
+        switch (aformat) {
+        case 16: nitems = alength / sizeof(short); break;
+        case 32: nitems = alength / sizeof(long); break;
+        default: nitems = alength;
+        }
+        mldata = copy_xdata (aformat, data, nitems);
+        g_free(data);
+        mltype = Val_GdkAtom (atype);
+        pair = alloc_small(2,0);
+        Field(pair,0) = mltype;
+        Field(pair,1) = mldata;
+        CAMLreturn(ml_some (pair));
+    }
+    return Val_unit;
+}
+
+ML_2 (gdk_property_delete, GdkWindow_val, GdkAtom_val, Unit)
 
 /* Region */
 
@@ -412,20 +526,28 @@ CAMLprim value ml_gdk_gc_get_values (value gc)
         tmp = ml_some(Val_GdkFont(values.font));
         Store_field(ret, 2, tmp);
     }
+    else
+      Store_field(ret, 2, Val_int(0));
     Field(ret,3) = Val_gdkFunction(values.function);
     Field(ret,4) = Val_gdkFill(values.fill);
     if (values.tile) {
         tmp = ml_some(Val_GdkPixmap(values.tile));
         Store_field(ret, 5, tmp);
     }
-    if (values.tile) {
+    else
+      Store_field(ret, 5, Val_int(0));
+    if (values.stipple) {
         tmp = ml_some(Val_GdkPixmap(values.stipple));
         Store_field(ret, 6, tmp);
     }
-    if (values.tile) {
+    else
+      Store_field(ret, 6, Val_int(0));
+    if (values.clip_mask) {
         tmp = ml_some(Val_GdkPixmap(values.clip_mask));
         Store_field(ret, 7, tmp);
     }
+    else
+      Store_field(ret, 7, Val_int(0));
     Field(ret,8) = Val_gdkSubwindowMode(values.subwindow_mode);
     Field(ret,9) = Val_int(values.ts_x_origin);
     Field(ret,10) = Val_int(values.ts_y_origin);
@@ -604,12 +726,27 @@ Make_Extractor (GdkEventProximity, GdkEvent_arg(Proximity), source,
 		Val_gdkInputSource)
 Make_Extractor (GdkEventProximity, GdkEvent_arg(Proximity), deviceid, Val_int)
 
+Make_Extractor (GdkEventClient, GdkEvent_arg(Client), window, Val_GdkWindow)
+Make_Extractor (GdkEventClient, GdkEvent_arg(Client), message_type, Val_int)
+CAMLprim value ml_GdkEventClient_data (value arg)
+{
+    GdkEventClient *ev = GdkEvent_arg(Client)(arg);
+    int nitems = 0;
+    switch (ev->data_format) {
+    case 8:  nitems = 20; break;
+    case 16: nitems = 10; break;
+    case 32: nitems = 5;  break;
+    }
+    return copy_xdata (ev->data_format, ev->data.b, nitems);
+}
+
 /* DnD */
 Make_Val_final_pointer (GdkDragContext, gdk_drag_context_ref, gdk_drag_context_unref, 0)
 Make_Flags_val (GdkDragAction_val)
 ML_3 (gdk_drag_status, GdkDragContext_val, Flags_GdkDragAction_val, Int_val, Unit)
 Make_Extractor (GdkDragContext, GdkDragContext_val, suggested_action, Val_gdkDragAction)
-value val_int(gpointer i)
+
+static value val_int(gpointer i)
 {
   return Val_int (GPOINTER_TO_INT(i));
 }
@@ -624,3 +761,24 @@ CAMLprim value ml_GdkDragContext_targets (value c)
 /* Misc */
 ML_0 (gdk_flush, Unit)
 ML_0 (gdk_beep, Unit)
+
+/* Input */
+void ml_gdk_input_function(gpointer data, gint src, GdkInputCondition cnd)
+{
+  value *clos_p = (value*)data;
+  callback(*clos_p, Val_unit);
+}
+void ml_gdk_input_destroy_notify(gpointer data)
+{
+    ml_global_root_destroy(data);
+}
+
+ML_1 (gdk_input_remove, Int_val, Unit)
+
+CAMLprim value ml_gdk_input_add (value src, value cond, value clos) 
+{
+  return Val_int( gdk_input_add( Int_val(src),
+				 Input_condition_val( cond ),
+				 ml_gdk_input_function,
+				 ml_global_root_new(clos)));
+}
