@@ -1,4 +1,4 @@
-/* $Id: ml_gdkpixbuf.c,v 1.4 2002/07/06 03:02:31 garrigue Exp $ */
+/* $Id: ml_gdkpixbuf.c,v 1.5 2002/10/25 10:08:48 garrigue Exp $ */
 
 #include <string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -97,12 +97,12 @@ value ml_gdk_pixbuf_render_pixmap_and_mask (value pixbuf, value thr)
     GdkBitmap *mask;
     gdk_pixbuf_render_pixmap_and_mask(GdkPixbuf_val(pixbuf), &pm, &mask,
 				      Int_val(thr));
-    vpm = Val_GdkPixmap(pm);
-    vmask = Val_GdkBitmap(mask);
+    vpm = Val_GdkPixmap_no_ref(pm);
+    vmask = Val_option(mask,Val_GdkBitmap_no_ref);
     ret = alloc_small(2,0);
     Field(ret,0) = vpm;
     Field(ret,1) = vmask;
-    return ret;
+    CAMLreturn(ret);
 }
 
 /* Fetching a region from a drawable */
